ActiveX / VBScript Chart Example

Chart Example
You must be running Microsoft Internet Explorer 3.0 and have the Microsoft ActiveX Chart Control installed to view this page.

The chart control enables you to draw charts. The chart's types and styles are properties of the control. The chart has one method, AboutBox. The chart generates no events.

Chart Type
Simple Pie | Simple Column
Pie with Wedge Out | Stacked Column
Simple Point | Full Column
Stacked Point | Simple Bar
Full Point | Stacked Bar
Simple Line | Full Bar
Stacked Line | HLC Stock
Full Line | HLC Stock WSJ
Simple Area | OHLC Stock
Stack Area | OHLC Stock WSJ
Full Area

Gridlines
Horizontal
Vertical
Background
Opaque
Transparent

Notes
The chart's properties on this page are changed by selecting the various radio buttons and check boxes. The OnClick event of these intrinsic controls calls VBScript procedures that change the chart properties.

The About Chart Control command button calls the chart's AboutBox method.

To view the source code for this page, select `Source` from the `View` menu.

If you have any questions or comments about this example, please send them to billr@smart.net. We would appreciate feedback and would like to hear about other developers' experiences with these new tools.